@@ -1,5 +1,5 @@
 # -*- coding: utf-8 -*-
-# Copyright 2020 Google LLC
+# Copyright 2022 Google LLC
 #
 # Licensed under the Apache License, Version 2.0 (the "License");
 # you may not use this file except in compliance with the License.
@@ -63,7 +63,8 @@ class SpecialistPoolServiceClientMeta(type):
     _transport_registry["grpc_asyncio"] = SpecialistPoolServiceGrpcAsyncIOTransport
 
     def get_transport_class(
-        cls, label: str = None,
+        cls,
+        label: str = None,
     ) -> Type[SpecialistPoolServiceTransport]:
         """Returns an appropriate transport class.
 
@@ -175,10 +176,16 @@ class SpecialistPoolServiceClient(metaclass=SpecialistPoolServiceClientMeta):
         return self._transport
 
     @staticmethod
-    def specialist_pool_path(project: str, location: str, specialist_pool: str,) -> str:
+    def specialist_pool_path(
+        project: str,
+        location: str,
+        specialist_pool: str,
+    ) -> str:
         """Returns a fully-qualified specialist_pool string."""
         return "projects/{project}/locations/{location}/specialistPools/{specialist_pool}".format(
-            project=project, location=location, specialist_pool=specialist_pool,
+            project=project,
+            location=location,
+            specialist_pool=specialist_pool,
         )
 
     @staticmethod
@@ -191,7 +198,9 @@ class SpecialistPoolServiceClient(metaclass=SpecialistPoolServiceClientMeta):
         return m.groupdict() if m else {}
 
     @staticmethod
-    def common_billing_account_path(billing_account: str,) -> str:
+    def common_billing_account_path(
+        billing_account: str,
+    ) -> str:
         """Returns a fully-qualified billing_account string."""
         return "billingAccounts/{billing_account}".format(
             billing_account=billing_account,
@@ -204,9 +213,13 @@ class SpecialistPoolServiceClient(metaclass=SpecialistPoolServiceClientMeta):
         return m.groupdict() if m else {}
 
     @staticmethod
-    def common_folder_path(folder: str,) -> str:
+    def common_folder_path(
+        folder: str,
+    ) -> str:
         """Returns a fully-qualified folder string."""
-        return "folders/{folder}".format(folder=folder,)
+        return "folders/{folder}".format(
+            folder=folder,
+        )
 
     @staticmethod
     def parse_common_folder_path(path: str) -> Dict[str, str]:
@@ -215,9 +228,13 @@ class SpecialistPoolServiceClient(metaclass=SpecialistPoolServiceClientMeta):
         return m.groupdict() if m else {}
 
     @staticmethod
-    def common_organization_path(organization: str,) -> str:
+    def common_organization_path(
+        organization: str,
+    ) -> str:
         """Returns a fully-qualified organization string."""
-        return "organizations/{organization}".format(organization=organization,)
+        return "organizations/{organization}".format(
+            organization=organization,
+        )
 
     @staticmethod
     def parse_common_organization_path(path: str) -> Dict[str, str]:
@@ -226,9 +243,13 @@ class SpecialistPoolServiceClient(metaclass=SpecialistPoolServiceClientMeta):
         return m.groupdict() if m else {}
 
     @staticmethod
-    def common_project_path(project: str,) -> str:
+    def common_project_path(
+        project: str,
+    ) -> str:
         """Returns a fully-qualified project string."""
-        return "projects/{project}".format(project=project,)
+        return "projects/{project}".format(
+            project=project,
+        )
 
     @staticmethod
     def parse_common_project_path(path: str) -> Dict[str, str]:
@@ -237,10 +258,14 @@ class SpecialistPoolServiceClient(metaclass=SpecialistPoolServiceClientMeta):
         return m.groupdict() if m else {}
 
     @staticmethod
-    def common_location_path(project: str, location: str,) -> str:
+    def common_location_path(
+        project: str,
+        location: str,
+    ) -> str:
         """Returns a fully-qualified location string."""
         return "projects/{project}/locations/{location}".format(
-            project=project, location=location,
+            project=project,
+            location=location,
         )
 
     @staticmethod
@@ -428,8 +453,7 @@ class SpecialistPoolServiceClient(metaclass=SpecialistPoolServiceClientMeta):
     ) -> gac_operation.Operation:
         r"""Creates a SpecialistPool.
 
-
-        .. code-block::
+        .. code-block:: python
 
             from google.cloud import aiplatform_v1beta1
 
@@ -530,7 +554,12 @@ class SpecialistPoolServiceClient(metaclass=SpecialistPoolServiceClientMeta):
         )
 
         # Send the request.
-        response = rpc(request, retry=retry, timeout=timeout, metadata=metadata,)
+        response = rpc(
+            request,
+            retry=retry,
+            timeout=timeout,
+            metadata=metadata,
+        )
 
         # Wrap the response in an operation future.
         response = gac_operation.from_gapic(
@@ -554,8 +583,7 @@ class SpecialistPoolServiceClient(metaclass=SpecialistPoolServiceClientMeta):
     ) -> specialist_pool.SpecialistPool:
         r"""Gets a SpecialistPool.
 
-
-        .. code-block::
+        .. code-block:: python
 
             from google.cloud import aiplatform_v1beta1
 
@@ -640,7 +668,12 @@ class SpecialistPoolServiceClient(metaclass=SpecialistPoolServiceClientMeta):
         )
 
         # Send the request.
-        response = rpc(request, retry=retry, timeout=timeout, metadata=metadata,)
+        response = rpc(
+            request,
+            retry=retry,
+            timeout=timeout,
+            metadata=metadata,
+        )
 
         # Done; return the response.
         return response
@@ -656,8 +689,7 @@ class SpecialistPoolServiceClient(metaclass=SpecialistPoolServiceClientMeta):
     ) -> pagers.ListSpecialistPoolsPager:
         r"""Lists SpecialistPools in a Location.
 
-
-        .. code-block::
+        .. code-block:: python
 
             from google.cloud import aiplatform_v1beta1
 
@@ -736,12 +768,20 @@ class SpecialistPoolServiceClient(metaclass=SpecialistPoolServiceClientMeta):
         )
 
         # Send the request.
-        response = rpc(request, retry=retry, timeout=timeout, metadata=metadata,)
+        response = rpc(
+            request,
+            retry=retry,
+            timeout=timeout,
+            metadata=metadata,
+        )
 
         # This method is paged; wrap the response in a pager, which provides
         # an `__iter__` convenience method.
         response = pagers.ListSpecialistPoolsPager(
-            method=rpc, request=request, response=response, metadata=metadata,
+            method=rpc,
+            request=request,
+            response=response,
+            metadata=metadata,
         )
 
         # Done; return the response.
@@ -762,8 +802,7 @@ class SpecialistPoolServiceClient(metaclass=SpecialistPoolServiceClientMeta):
         in the pool.
 
 
-
-        .. code-block::
+        .. code-block:: python
 
             from google.cloud import aiplatform_v1beta1
 
@@ -855,7 +894,12 @@ class SpecialistPoolServiceClient(metaclass=SpecialistPoolServiceClientMeta):
         )
 
         # Send the request.
-        response = rpc(request, retry=retry, timeout=timeout, metadata=metadata,)
+        response = rpc(
+            request,
+            retry=retry,
+            timeout=timeout,
+            metadata=metadata,
+        )
 
         # Wrap the response in an operation future.
         response = gac_operation.from_gapic(
@@ -882,8 +926,7 @@ class SpecialistPoolServiceClient(metaclass=SpecialistPoolServiceClientMeta):
     ) -> gac_operation.Operation:
         r"""Updates a SpecialistPool.
 
-
-        .. code-block::
+        .. code-block:: python
 
             from google.cloud import aiplatform_v1beta1
 
@@ -984,7 +1027,12 @@ class SpecialistPoolServiceClient(metaclass=SpecialistPoolServiceClientMeta):
         )
 
         # Send the request.
-        response = rpc(request, retry=retry, timeout=timeout, metadata=metadata,)
+        response = rpc(
+            request,
+            retry=retry,
+            timeout=timeout,
+            metadata=metadata,
+        )
 
         # Wrap the response in an operation future.
         response = gac_operation.from_gapic(
